"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var core_1 = require("@angular/core");
var ElasticInputDirective = (function () {
    function ElasticInputDirective(element) {
        this.element = element;
    }
    ElasticInputDirective.prototype.onInput = function () {
        this.update();
    };
    ElasticInputDirective.prototype.ngOnInit = function () {
        this.wrapper = document.createElement('div');
        this.wrapper.style.position = 'fixed';
        this.wrapper.style.top = '-999px';
        this.wrapper.style.left = '0';
        document.body.appendChild(this.wrapper);
        this.mirror = document.createElement('span');
        this.mirror.style.whiteSpace = 'pre';
        this.setMirrorStyle(this.mirror, this.element.nativeElement);
        this.wrapper.appendChild(this.mirror);
        this.update();
    };
    ElasticInputDirective.prototype.ngAfterContentChecked = function () {
        this.update();
    };
    ElasticInputDirective.prototype.ngOnDestroy = function () {
        this.mirror.remove();
        this.wrapper.remove();
    };
    ElasticInputDirective.prototype.setMirrorStyle = function (mirror, element) {
        var style = window.getComputedStyle(element);
        ['fontFamily', 'fontSize', 'fontWeight', 'fontStyle',
            'letterSpacing', 'textTransform', 'wordSpacing'].forEach(function (value) {
            mirror.style[value] = style[value];
        });
        mirror.style.paddingLeft = style.textIndent;
        if (style.boxSizing === 'border-box') {
            ['paddingLeft', 'paddingRight', 'borderLeftStyle', 'borderLeftWidth',
                'borderRightStyle', 'borderRightWidth'].forEach(function (value) {
                mirror.style[value] = style[value];
            });
        }
        else if (style.boxSizing === 'padding-box') {
            ['paddingLeft', 'paddingRight'].forEach(function (value) {
                mirror.style[value] = style[value];
            });
        }
    };
    ElasticInputDirective.prototype.update = function () {
        this.mirror.innerText = this.element.nativeElement.value;
        var delta = 1;
        this.element.nativeElement.style.width = this.mirror.offsetWidth + delta + "px";
    };
    return ElasticInputDirective;
}());
ElasticInputDirective.decorators = [
    { type: core_1.Directive, args: [{
                selector: 'input[elastic-input]'
            },] },
];
/** @nocollapse */
ElasticInputDirective.ctorParameters = function () { return [
    { type: core_1.ElementRef, },
]; };
ElasticInputDirective.propDecorators = {
    'onInput': [{ type: core_1.HostListener, args: ['input', ['$event.target'],] },],
};
exports.ElasticInputDirective = ElasticInputDirective;
//# sourceMappingURL=elastic-input.directive.js.map